@@ -1,5 +1,5 @@
-"""
-PSUtils I/O utilities.
+"""PSUtils I/O utilities.
+
 Copyright (c) Reuben Thomas 2023.
 Released under the GPL version 3, or (at your option) any later version.
 """
@@ -7,10 +7,11 @@ Released under the GPL version 3, or (at your option) any later version.
 import io
 import os
 import sys
+from collections.abc import Iterator
 from contextlib import contextmanager
-from typing import Tuple, Optional, Iterator, IO
+from typing import IO, Optional
 
-import puremagic  # type: ignore
+import puremagic
 
 from .warnings import die
 
@@ -18,13 +19,13 @@ from .warnings import die
 @contextmanager
 def setup_input_and_output(
     infile_name: Optional[str], outfile_name: Optional[str]
-) -> Iterator[Tuple[IO[bytes], str, IO[bytes]]]:
+) -> Iterator[tuple[IO[bytes], str, IO[bytes]]]:
     # Set up input
     infile: Optional[IO[bytes]] = None
     if infile_name is not None:
         try:
             infile = open(infile_name, "rb")
-        except IOError:
+        except OSError:
             die(f"cannot open input file {infile_name}")
     else:
         infile = os.fdopen(sys.stdin.fileno(), "rb", closefd=False)
@@ -40,7 +41,7 @@ def setup_input_and_output(
     if outfile_name is not None:
         try:
             outfile = open(outfile_name, "wb")
-        except IOError:
+        except OSError:
             die(f"cannot open output file {outfile_name}")
     else:
         outfile = os.fdopen(sys.stdout.fileno(), "wb", closefd=False)
